% cl_ctcb.m
%
% Cruisebuilder main code
% 
% Usage: cl_ct
% Click on help buttons for tips.
% Version 1.7, 11 June 2008, Chris Linder
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Track type - set to 'rh' for rhumb line 
% method, 'gc' for great circle method
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if nmmode==1
    tracktype='rh';
elseif nmmode==2
    tracktype='gc';
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Error check
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

cl_cterror;
cbruns=100;

if(cbgoodflag)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initialize variables and plot initial map
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

cbruns=cbruns+1;

clear('waypts*');

%offset for m_text
err=0.1;

% Retain original lat/lon limits...
origminlon=minlon;
origmaxlon=maxlon;
origminlat=minlat;
origmaxlat=maxlat;


eval(sprintf('f%d=figure;',cbruns));
title('Drawing basemap...');
m_proj('Mercator','lon',[minlon maxlon],'lat',[minlat maxlat]);

switch btmode
case 1
  [data,LON,LAT]=m_etopo2([minlon maxlon minlat maxlat]);
case 2
  [data,LON,LAT]=m_tbase([minlon maxlon minlat maxlat]);
case 3
  if exist(btfile) == 2
    eval(sprintf('load %s;',btfile));
  else
    eval(sprintf('msgbox(''Note!  %s not found - using Terrainbase'',''Note'',''warn'');',btfile)); 
    eval(sprintf('figure(f%d);',cbruns));
    [data,LON,LAT]=m_tbase([minlon maxlon minlat maxlat]);
  end;
end;
eval(sprintf('posit=get(f%d,''position'');',cbruns));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Create mercator map based on user-defined box 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ft=maxlat-minlat;
fn=maxlon-minlon;
eval(sprintf('figure(f%d);',cbruns));
m_grid('box','fancy'); 
set(findobj('tag','m_grid_color'),'facecolor','none');
hold on;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Plot common plotting options
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

cl_ctcbplots;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Zoom in
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

eval(sprintf('figure(f%d);',cbruns));
title('Pick upper left corner of zoom box with LMB (RMB when done.)');
[xUL,yUL,button]=ginput(1);    
while button==1  % This keeps looping the zoom box feature until the RMB is pressed
  oldminlon=minlon;
  oldmaxlon=maxlon;
  oldminlat=minlat;
  oldmaxlat=maxlat;
  [minlon,maxlat]=m_xy2ll(xUL,yUL);    
  hold on;
  redbox1=[oldminlon oldminlat; oldminlon oldmaxlat; minlon oldmaxlat; minlon oldminlat];
  redbox2=[minlon maxlat; minlon oldmaxlat; oldmaxlon oldmaxlat; oldmaxlon maxlat];
  m_patch(redbox1(:,1),redbox1(:,2),'k');
  m_patch(redbox2(:,1),redbox2(:,2),'k');

  title('Pick lower right corner of zoom box with LMB.  Abort with RMB.');
  [xLR,yLR,button]=ginput(1);    

  if button==1  % Continue zooming...
    [maxlon,minlat]=m_xy2ll(xLR,yLR);    hold on;
    redbox3=[minlon oldminlat; minlon minlat; maxlon minlat; maxlon oldminlat];
    redbox4=[maxlon oldminlat; maxlon oldmaxlat; oldmaxlon oldmaxlat; oldmaxlon oldminlat];
    m_patch(redbox3(:,1),redbox3(:,2),'k');
    m_patch(redbox4(:,1),redbox4(:,2),'k');
    title('Area selected, resizing...');
    pause(.25);
    clf;
    m_proj('Mercator','lon',[minlon maxlon],'lat',[minlat maxlat]);
    m_grid('box','fancy'); 
    hold on;
    title('Area selected, resizing...');
    ft=maxlat-minlat;
    fn=maxlon-minlon;
    % At this point we need to replot the bathy and other points
    cl_ctcbplots;
    m_grid('box','fancy'); 
  else
    minlon=oldminlon;
    maxlat=oldmaxlat;
    title('Reloading bathy and coastlines...');
    pause(.25);
    m_ungrid patch;
    hold on;
    title('Reloading bathy and coastlines...');
  end;

  title('Pick upper left corner of zoom box with LMB (RMB when done.)');
  [xUL,yUL,button]=ginput(1); 
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Pick points
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

numsections=0;
continue_ans='Continue';
while strcmp(continue_ans,'Continue') % Keeps getting more sections until user terminates - this is the section loop!
  mode_ans=questdlg('Enter sectionmode for this section:','Choose mode','Random','Fixed distance','Fixed depth','Fixed distance');
  switch mode_ans
  case 'Random'
    cbmode=1;
  case 'Fixed distance'
    cbmode=2;
    answers=inputdlg({'Enter new spacing in km',},'Fixed spatial spacing selected',[1],{num2str(kmspacing)});
    if(isempty(answers))      
    else
      kmspacing=str2num(answers{1});
      set(en_kmspacing,'string',num2str(kmspacing));
    end;
  case 'Fixed depth'
    cbmode=3;
    answers=inputdlg({'Enter new spacing in m',},...
                      'Fixed depth spacing selected',[1],...
                      {num2str(depthspacing)});
    if(isempty(answers))
    else 
      depthspacing=str2num(answers{1});
      set(en_depthspacing,'string',num2str(depthspacing));
    end;
    answers=inputdlg({'Enter new max horizontal spacing in km',},...
                      'Fixed depth spacing selected',[1],...
                      {num2str(maxkmspacing)});
    if(isempty(answers))
    else 
      maxkmspacing=str2num(answers{1});
      set(en_maxkmspacing,'string',num2str(maxkmspacing));
    end;
  end;
  waypts=[];
  button=1;
  numsections=numsections+1;
  switch cbmode
  case 1 % Regular point-picking mode...
    eval(sprintf('f%d_%d=figure;',cbruns,numsections));
    disp('You have chosen manual station choosing.  Pick away!');
    eval(sprintf('figure(f%d);',cbruns));
    title('Choose points with LMB, RMB when done.');
    numpts=0;
    [x,y,button]=ginput(1);
    while button==1  % Looping through the point picker
      numpts=numpts + 1;
      [lon,lat]=m_xy2ll(x,y);
      if numpts==1
        startlat=lat; startlon=lon;
        m_text(lon+err,lat+err,['Start #',num2str(numsections)],'color','b');
      end;
      waypts=[waypts; numpts lat lon abs(interp2(LON,LAT,data,lon,lat))];
      m_text(lon+err,lat+err,num2str(numpts));
      m_plot(lon,lat,'ro');
      m_plot(lon,lat,'k.');
      if numpts > 1
        m_plot(waypts(numpts-1:numpts,3),waypts(numpts-1:numpts,2),'r');
      end;
      eval(sprintf('figure(f%d_%d);',cbruns,numsections));
      distfmstart=deg2km(distance(tracktype,startlat,startlon,lat,lon));
      hold on; plot(distfmstart,-1*abs(interp2(LON,LAT,data,lon,lat)),'r*');
      grid on;
      text(distfmstart,-1*abs(interp2(LON,LAT,data,lon,lat))+30,num2str(numpts));
      eval(sprintf('figure(f%d);',cbruns));
      [x,y,button]=ginput(1);
    end;
    if(isempty(waypts))==0
      m_text(lon+err,lat+err,['End #',num2str(numsections)],'color','b');
      eval(sprintf('figure(f%d_%d);',cbruns,numsections));
      eval(sprintf('title(''Section #%d bathymetry profile'');',numsections));
      eval(sprintf('figure(f%d);',cbruns));
      eval(sprintf('waypts_%d=waypts',numsections));
    end;

  case 2 % Sectionmode fixed km 
    % First, get/plot the line that you are picking points along
    disp('You have chosen sectionmode fixed km spacing.  Pick section endpoints w/LMB.');

    eval(sprintf('figure(f%d);',cbruns));
    title('Pick START of section with LMB.');
    [x,y]=ginput(1);
    [bathy1lon,bathy1lat]=m_xy2ll(x,y);

    % C. MAURITZEN modification: this code allows users to pick exact lat/lons
    if(latlonconfirm)
       newmodifiedlat=inputdlg({'',},'You just chose this latitude.  Modify ?',[1],{num2str(bathy1lat)});
       if(isempty(newmodifiedlat))
       else
         bathy1lat=str2num(newmodifiedlat{1});
       end;    
       newmodifiedlon=inputdlg({'',},'You just chose this longitude.  Modify ?',[1],{num2str(bathy1lon)});
       if(isempty(newmodifiedlon))
       else
         bathy1lon=str2num(newmodifiedlon{1});
       end;  
    end;
    
    m_plot(bathy1lon,bathy1lat,'b.');
    m_text(bathy1lon+err,bathy1lat+err,['Start #',num2str(numsections)],'color','b');

    eval(sprintf('figure(f%d);',cbruns));
    title('Pick END of section with LMB.');
    [x2,y2]=ginput(1);
    title(['The computer is picking points for section # ',num2str(numsections),'... Please wait!']);
    [bathy2lon,bathy2lat]=m_xy2ll(x2,y2);

    % C. MAURITZEN modification: this code allows users to pick exact lat/lons
    if(latlonconfirm)
       newmodifiedlat=inputdlg({'',},'You just chose this latitude.  Modify ?',[1],{num2str(bathy2lat)});
       if(isempty(newmodifiedlat))
       else
         bathy2lat=str2num(newmodifiedlat{1});
       end;    
       newmodifiedlon=inputdlg({'',},'You just chose this longitude.  Modify ?',[1],{num2str(bathy2lon)});
       if(isempty(newmodifiedlon))
       else
         bathy2lon=str2num(newmodifiedlon{1});
       end; 
    end;
    
    m_plot(bathy2lon,bathy2lat,'b.');
    m_text(bathy2lon+err,bathy2lat+err,['End #',num2str(numsections)],'color','b');

    m_plot([bathy1lon bathy2lon],[bathy1lat bathy2lat]);
    startlon=bathy1lon;
    startlat=bathy1lat;
    disp(' ');
    disp(['The computer is picking points for section # ',num2str(numsections),'... Please wait!']);
    
    % Let's put an option in here to plot the bathymetry along this line
    % Need to do this:  find 100 equally spaced points along chosen line.
    % Reckoning.  Interp2 command.  Find distances in km along line.  Plot.
    
    rng=distance(tracktype,bathy1lat,bathy1lon,bathy2lat,bathy2lon);
    azm=azimuth(tracktype,bathy1lat,bathy1lon,bathy2lat,bathy2lon);
    profile=[]; rngstep=0;
    for loop=1:100
      [newlat,newlon]=reckon(tracktype,bathy1lat,bathy1lon,rngstep,azm);
      
      % dateline hack-- if bathy1lat is on the west side of the dateline,
      % need to put in hack to make sure that newlon is a NEGATIVE value
      % and not positive, to match the bathy file.
      
      if abs(bathy1lon-newlon) > 180
          newlon = newlon - 360;
      end;
      
      profile=[profile; deg2km(rngstep) -1*abs(interp2(LON,LAT,data,newlon,newlat))];
      rngstep=rngstep + rng/100; 
     
    end;
    eval(sprintf('profile_%d=profile;',numsections));
    eval(sprintf('f%d_%d=figure;',cbruns,numsections));
    plot(profile(:,1),profile(:,2)); 
    eval(sprintf('title(''Bathy profile #%d - interpolated horizontal bathy resolution %6.2f km'');',numsections,deg2km(rng/100)));
    xlabel('Distance from first point (km)');
    ylabel('Depth (m)');
    grid on;
    YL=ylim;
    ylim([YL(1) 0]);
    eval(sprintf('figure(f%d);',cbruns));
    title('Choosing stations...');
    disp(' ');

    % Fixed station spacing
    %ok, now need to find out number of stations for the section, then start at startlat/lon, and 
    %increment the distance, find lat/lons of stations using reckon.  We already have length of
    %section, and the azimuth for reckon...

    eval(sprintf('figure(f%d);',cbruns));
    lengthofsection=deg2km(rng);
    numstations=ceil(lengthofsection/kmspacing);
    disp(['You have chosen fixed station spacing of ',num2str(kmspacing),'km - this gives you ',num2str(numstations),' stations']);
    rngstep=0;
    numpts=0;
    for stationloop=1:numstations  % Looping through the point picker
      numpts=numpts+1;
      [newlat,newlon]=reckon(tracktype,bathy1lat,bathy1lon,km2deg(rngstep),azm);
            
      % dateline hack-- if bathy1lat is on the west side of the dateline,
      % need to put in hack to make sure that newlon is a NEGATIVE value
      % and not positive, to match the bathy file.
      
      if abs(bathy1lon-newlon) > 180
          newlon = newlon - 360;
      end;
   
      waypts=[waypts; stationloop newlat newlon abs(interp2(LON,LAT,data,newlon,newlat))];
      rngstep=rngstep + kmspacing;
      m_text(newlon+err,newlat+err,num2str(numpts));
      m_plot(newlon,newlat,'ro');
      m_plot(newlon,newlat,'k.');
      m_plot(waypts(:,3),waypts(:,2),'r');
      eval(sprintf('figure(f%d_%d);',cbruns,numsections));
      distfmstart=deg2km(distance(tracktype,startlat,startlon,newlat,newlon));
      hold on; plot(distfmstart,-1*abs(interp2(LON,LAT,data,newlon,newlat)),'r*');
      text(distfmstart,-1*abs(interp2(LON,LAT,data,newlon,newlat))+30,num2str(numpts));
      grid on;
      eval(sprintf('figure(f%d);',cbruns));
    end; %stationloop
    eval(sprintf('waypts_%d=waypts',numsections));


  case 3 % Sectionmode fixed depth
    % First, get/plot the line that you are picking points along
    disp('You have chosen fixed depth spacing.  Pick endpoints w/LMB.');
    eval(sprintf('figure(f%d);',cbruns));
    title('Pick START of section with LMB.');
    [x,y]=ginput(1);
    [bathy1lon,bathy1lat]=m_xy2ll(x,y);

    % C. MAURITZEN modification: this code allows users to pick exact lat/lons
    if(latlonconfirm)
       newmodifiedlat=inputdlg({'',},'You just chose this latitude.  Modify ?',[1],{num2str(bathy1lat)});
       if(isempty(newmodifiedlat))
       else
         bathy1lat=str2num(newmodifiedlat{1});
       end;    
       newmodifiedlon=inputdlg({'',},'You just chose this longitude.  Modify ?',[1],{num2str(bathy1lon)});
       if(isempty(newmodifiedlon))
       else
         bathy1lon=str2num(newmodifiedlon{1});
       end;  
    end;
    
    m_plot(bathy1lon,bathy1lat,'b.');
    m_text(bathy1lon+err,bathy1lat+err,['Start #',num2str(numsections)],'color','b');

    eval(sprintf('figure(f%d);',cbruns));
    title('Pick END of section with LMB.');
    [x2,y2]=ginput(1);
    title(['The computer is picking points for section # ',num2str(numsections),'... Please wait!']);
    [bathy2lon,bathy2lat]=m_xy2ll(x2,y2);

    % C. MAURITZEN modification: this code allows users to pick exact lat/lons
    if(latlonconfirm)
       newmodifiedlat=inputdlg({'',},'You just chose this latitude.  Modify ?',[1],{num2str(bathy2lat)});
       if(isempty(newmodifiedlat))
       else
         bathy2lat=str2num(newmodifiedlat{1});
       end;    
       newmodifiedlon=inputdlg({'',},'You just chose this longitude.  Modify ?',[1],{num2str(bathy2lon)});
       if(isempty(newmodifiedlon))
       else
          bathy2lon=str2num(newmodifiedlon{1});
       end; 
    end;
    
    m_plot(bathy2lon,bathy2lat,'b.');
    m_text(bathy2lon+err,bathy2lat+err,['End #',num2str(numsections)],'color','b');

    m_plot([bathy1lon bathy2lon],[bathy1lat bathy2lat]);
    startlon=bathy1lon;
    startlat=bathy1lat;
    disp(' ');
    disp(['The computer is picking points for section # ',num2str(numsections),'... Please wait!']);
    
    % Plot the bathymetry along this line
    % Need to do this:  find 100 equally spaced points along chosen line.
    % Reckoning.  Interp2 command.  Find distances in km along line.  Plot.
    
    rng=distance(tracktype,bathy1lat,bathy1lon,bathy2lat,bathy2lon);
    azm=azimuth(tracktype,bathy1lat,bathy1lon,bathy2lat,bathy2lon);
    profile=[]; rngstep=0;
    for loop=1:250
      [newlat,newlon]=reckon(tracktype,bathy1lat,bathy1lon,rngstep,azm);
                  
      % dateline hack-- if bathy1lat is on the west side of the dateline,
      % need to put in hack to make sure that newlon is a NEGATIVE value
      % and not positive, to match the bathy file.
      
      if abs(bathy1lon-newlon) > 180
          newlon = newlon - 360;
      end;
      
      profile=[profile; deg2km(rngstep) -1*abs(interp2(LON,LAT,data,newlon,newlat))];
      rngstep=rngstep + rng/250;
    end;
    eval(sprintf('profile_%d=profile;',numsections));
    eval(sprintf('f%d_%d=figure;',cbruns,numsections));
    plot(profile(:,1),profile(:,2)); 
    eval(sprintf('title(''Bathy profile #%d - interpolated horizontal bathy resolution %6.2f km'');',numsections,deg2km(rng/500)));
    xlabel('Distance from first point (km)');
    ylabel('Depth (m)');
    grid on;
    YL=ylim;
    ylim([YL(1) 0]);
    eval(sprintf('figure(f%d);',cbruns));
    title('Choosing stations...');
    disp(' ');

    % Fixed depth spacing
    % ok, for this we already have a profile of 500 equally spaced points along a line - this should
    % be more than enough to simply step through and "accumulate" delta-depth.  (First find out if we're going up/down.)
    % When depthspacing is reached, we can plop down a point, and set accumdelta-depth to zero, and repeat.
    % Needs to work given any kind of bathy profile.

    eval(sprintf('figure(f%d);',cbruns));
    disp(['You have chosen fixed depth station spacing of ',num2str(depthspacing),'m']);
    rngstep=0;
    numpts=0;
    profileindex=1;
    lengthofsection=deg2km(rng);

    while (rngstep < lengthofsection) & (profileindex < size(profile,1))  % Looping through the point picker
      numpts=numpts+1;
      [newlat,newlon]=reckon(tracktype,bathy1lat,bathy1lon,km2deg(rngstep),azm);
                  
      % dateline hack-- if bathy1lat is on the west side of the dateline,
      % need to put in hack to make sure that newlon is a NEGATIVE value
      % and not positive, to match the bathy file.
      
      if abs(bathy1lon-newlon) > 180
          newlon = newlon - 360;
      end;
      
      newdepth=-1*abs(interp2(LON,LAT,data,newlon,newlat));
      waypts=[waypts; numpts newlat newlon abs(newdepth)];
      m_text(newlon+err,newlat+err,num2str(numpts));
      m_plot(newlon,newlat,'ro');
      m_plot(newlon,newlat,'k.');
      m_plot(waypts(:,3),waypts(:,2),'r');
      eval(sprintf('figure(f%d_%d);',cbruns,numsections));
      distfmstart=deg2km(distance(tracktype,startlat,startlon,newlat,newlon));
      hold on; plot(distfmstart,newdepth,'r*');
      text(distfmstart,newdepth+30,num2str(numpts));
      grid on;
      eval(sprintf('figure(f%d);',cbruns));
      
      endflag=0;
      while (abs(profile(profileindex,2)-newdepth) < depthspacing) && (endflag==0)
        profileindex=profileindex+1;
        % Now, if the profileindex count exceeds the length of profile, that's it, the section is done! (unless you can fit more
        % in with maxkmspacing...
        if profileindex>size(profile,1)
          profileindex=size(profile,1);
          endflag=1;
        end;
      end;
      rnginc=profile(profileindex,1)-rngstep;
      if rnginc > maxkmspacing  % say the profile is too flat - need to enforce limit
        rnginc=maxkmspacing;
        %  Also need to set the profileindex back!
        while profile(profileindex,1) > (rngstep+rnginc)
          profileindex = profileindex - 1;
        end;
      end;
      rngstep=rngstep + rnginc;
    end; %stationloop
    eval(sprintf('waypts_%d=waypts',numsections));
  end;

  continue_ans=questdlg('Do you wish to continue picking sections?','Continue?','Continue','Done','Continue');
  m_grid('box','fancy'); set(findobj('tag','m_grid_color'),'facecolor','none');
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% option to save waypoints for use in cl_ct.m
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

saveout_ans=questdlg('Do you wish to save your work?','Save?','Yes','No','Yes');
if strcmp(saveout_ans,'Yes')
  answers=inputdlg({'Enter output file prefix',},'Save files',[1],{'waypoints'});
  cboutfile=answers{1};
  for loop=1:numsections
    eval(sprintf('A=waypts_%d;',loop));
    eval(sprintf('outfile=''%s_%d'';',cboutfile,loop));
    fido=fopen(outfile,'w+');
    fprintf(fido,'%4.0f %9.4f %9.4f\t %7.0f\n',A');
    fclose(fido);
  end;
end;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% option to save waypoints for bridge
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

bridgesaveout_ans=questdlg('Do you wish to save these waypoint files for bridge?','Save?','Yes','No','Yes');
if strcmp(bridgesaveout_ans,'Yes')
  bridgefileprefix=['bridge_' cboutfile];
  answers=inputdlg({'Enter output file prefix for bridge',},'Save files',[1],{bridgefileprefix});
  if(isempty(answers))
  else
    bridgefileprefix=answers{1};
  end;    
  for loop=1:numsections
    eval(sprintf('A=waypts_%d;',loop));
    eval(sprintf('outfile=''%s_%d'';',bridgefileprefix,loop));
    fido=fopen(outfile,'w+');
    sta=A(:,1);
    bd=A(:,4);
    latd=fix(A(:,2));
    latm=(A(:,2)-latd)*60;
    lond=fix(A(:,3));
    lonm=(A(:,3)-lond)*60;
    out=[sta latd latm lond lonm bd];
    A=out';
    fprintf(fido,'Station   Latitude +N/-S  Longitude +E/-W Approx. Depth (m)\n\n');
    fprintf(fido,'%2.0f\t %3.0f %7.1f\t %3.0f %7.1f %12.0f\n',A);
    fclose(fido);
  end;
end;


end; %cbgoodflag

% Refresh original lat/lon limits...
minlon=origminlon;
maxlon=origmaxlon;
minlat=origminlat;
maxlat=origmaxlat;
