% cl_ctloadcomp.m
%
% Cruisetrack loading/computing code
% 
% Usage: cl_ct
% Click on help buttons for tips.
% Version 1.7, 11 June 2008, Chris Linder
%

% Need to load all of the applicable track data
% First, if number of sections is 1, then just load the inputfile
% or, if number of sections > 1, then load all sections.

% First, check to make sure files are present...

% Error checks for Cruisetrack

ctgoodflag=1;

if isempty(numsec)
  eval(sprintf('if exist(''%s'')==0 msgbox(''Warning!  %s (inputfile) not found!'',''Error'',''error''); ctgoodflag=0; end;',inputfile,inputfile));
else
  for checkloop=1:numsec
    eval(sprintf('if exist(''%s_%d'')==0 msgbox(''Warning!  %s_%d (inputfile) not found!'',''Error'',''error''); ctgoodflag=0; end;',inputfile,checkloop,inputfile,checkloop));
  end;    
end;
if isempty(trackfile1) == 0
  eval(sprintf('if exist(''%s'')==0 msgbox(''Warning!  %s (trackfile1) not found!'',''Error'',''error''); ctgoodflag=0; end;',trackfile1,trackfile1));
end;
if isempty(trackfile2) == 0
  eval(sprintf('if exist(''%s'')==0 msgbox(''Warning!  %s (trackfile2) not found!'',''Error'',''error''); ctgoodflag=0; end;',trackfile2,trackfile2));
end;

if(ctgoodflag)
   
wirerate=wiretime/60000; % this is the wiretime (mins per 1000m) / 60mins / 1000m

alldata=[];
numrows=[];

% Load trackfile1, if anything other than none is selected
if isempty(trackfile1) == 0
  eval(sprintf('t1=load(''%s'');',trackfile1));
  if isempty(numsec)
    eval(sprintf('section1=load(''%s'');',inputfile));
  else
    eval(sprintf('section1=load(''%s_1'');',inputfile));
  end;
  t1=[t1; section1(1,2:3)];
  [t1rows,t1cols]=size(t1);
  t1=[ones(t1rows,1)*NaN t1 ones(t1rows,1)*NaN];
  t1dist=sum(sw_dist(t1(:,2),t1(:,3)));
  t1time=t1dist/speedtransit;
else
  t1=[]; t1rows=0; t1time=0;
end;
alldata=[alldata; t1];

% Compute sections and transits in between sections
transittime=[];
sectiontime=[];
onstatime=[];

if isempty(numsec) | numsec==1  % There are NO transits if there is 1 section
  if isempty(numsec)
    eval(sprintf('section1=load(''%s'');',inputfile));
  else
    eval(sprintf('section1=load(''%s_1'');',inputfile));
  end;
  sectiontime=sum(sw_dist(section1(:,2),section1(:,3)))/speedsec;
  depthofcast=abs(section1(:,4));
  onstatime=sum(depthofcast) * wirerate;
  alldata=[alldata; section1];
  [secrows,seccols]=size(section1);
  numrows=[numrows; secrows];
else % If numsec > 1, there are always numsec-1 transits
  numtransits=numsec-1;
  for loop=1:numsec-1
    % Compute section time
    eval(sprintf('section%d=load(''%s_%d'');',loop,inputfile,loop));
    eval(sprintf('alldata=[alldata; section%d];',loop));
    eval(sprintf('[sec%drows,sec%dcols]=size(section%d);',loop,loop,loop));
    eval(sprintf('sectiontime=[sectiontime; sum(sw_dist(section%d(:,2),section%d(:,3)))/speedsec];',loop,loop));
    eval(sprintf('depthofcast=abs(section%d(:,4));',loop));
    onstatime=[onstatime; (sum(depthofcast) * wirerate)];
    eval(sprintf('numrows=[numrows; sec%drows];',loop));

    % Compute transit time between sections
    eval(sprintf('section%d=load(''%s_%d'');',loop+1,inputfile,loop+1));
    eval(sprintf('lastoffirst=section%d(size(section%d,1),:);',loop,loop));
    eval(sprintf('firstofnext=section%d(1,:);',loop+1));
    eval(sprintf('transit%d=[lastoffirst; firstofnext];',loop));
    eval(sprintf('alldata=[alldata; transit%d];',loop));
    eval(sprintf('[tran%drows,tran%dcols]=size(transit%d);',loop,loop,loop));
    eval(sprintf('transittime=[transittime; sum(sw_dist(transit%d(:,2),transit%d(:,3)))/speedtransit];',loop,loop));
    %eval(sprintf('numrows=[numrows; tran%drows];',loop));
  end;
  % Gotta add the last section...
  eval(sprintf('alldata=[alldata; section%d];',numsec));
  eval(sprintf('[sec%drows,sec%dcols]=size(section%d);',numsec,numsec,numsec));
  eval(sprintf('sectiontime=[sectiontime; sum(sw_dist(section%d(:,2),section%d(:,3)))/speedsec];',numsec,numsec));
  eval(sprintf('depthofcast=abs(section%d(:,4));',numsec));
  onstatime=[onstatime; (sum(depthofcast) * wirerate)];
  eval(sprintf('numrows=[numrows; sec%drows];',numsec));
end;

% Load trackfile2, if anything other than none is selected

if isempty(trackfile2) == 0
  eval(sprintf('t2=load(''%s'');',trackfile2));
  [r,c]=size(alldata);
  t2=[alldata(r,2) alldata(r,3); t2];
  [t2rows,t2cols]=size(t2);
  t2=[ones(t2rows,1)*NaN t2 ones(t2rows,1)*NaN];
  t2dist=sum(sw_dist(t2(:,2),t2(:,3)));
  t2time=t2dist/speedtransit;
else
  t2=[]; t2rows=0; t2time=0;
end;
alldata=[alldata; t2];

hoursfudge = numfudge * durfudge;
totalsciencetime = sum(sectiontime) + sum(onstatime);
if weather==0
  hourslost=0;
else
  hourslost = totalsciencetime / weather;
end;
totaltransittime = sum(transittime) + t1time + t2time;
totalhours = hoursfudge + totaltransittime + totalsciencetime + hourslost;

totaldays=totalhours/24;

% Also want a nice cruisetrack.out file... ugh.
% For this we need to have the date at each "event" - make "waypoints" file
% Array output will have following columns
% 1: Index number 1 through number of sections
% 2: Start JD of the section
% 3: Starting Lat of section
% 4: Starting Lon of section
% 5: Number of points to each section
% 6: Hours steaming each section
% 7: Wire hours
% 8: Weather hours
% 9: Fudge hours
% 10: End JD of the section
% 11: Ending Lat of section
% 12: Ending Lon of section
% 13: Time to next station (transit time in hours) (note that transittime(numsec) (last one) == 0!)

beginjd=cl_ctjd(startyear,startmonth,startday,starthour);
startsecjd=beginjd + t1time/24;
transittime=[transittime; 0];
if isempty(numsec) | numsec==1
  loop=1;
  output=[1 ones(1,3)*0 numrows sectiontime onstatime ones(1,5)*0 transittime];
  startsecjd=beginjd+t1time/24;
  output(loop,2)=startsecjd;
  sectsciencehours=output(loop,6) + output(loop,7);
  hourslostpersect=sectsciencehours/totalsciencetime * hourslost;
  output(loop,8)=hourslostpersect;
  fudgehourspersect=sectsciencehours/totalsciencetime * hoursfudge;
  output(loop,9)=fudgehourspersect;
  endsecjd=output(loop,2) + sectsciencehours/24 + hourslostpersect/24 + fudgehourspersect/24;
  output(loop,10)=endsecjd;
  eval(sprintf('output(%d,3:4)=[section%d(1,2) section%d(1,3)];',loop,loop,loop));
  eval(sprintf('output(%d,11:12)=[section%d(numrows(%d),2) section%d(numrows(%d),3)];',loop,loop,loop,loop,loop));
else
  output=[(1:numsec)' ones(numsec,3)*0 numrows sectiontime onstatime ones(numsec,5)*0 transittime];
  for loop=1:numsec-1
    if loop==1
      output(loop,2)=startsecjd;
    end;
    sectsciencehours=output(loop,6) + output(loop,7);
    hourslostpersect=sectsciencehours/totalsciencetime * hourslost;
    output(loop,8)=hourslostpersect;
    fudgehourspersect=sectsciencehours/totalsciencetime * hoursfudge;
    output(loop,9)=fudgehourspersect;
    endsecjd=output(loop,2) + sectsciencehours/24 + hourslostpersect/24 + fudgehourspersect/24;
    output(loop,10)=endsecjd;
    output(loop+1,2)=endsecjd + output(loop,13)/24;
    eval(sprintf('output(%d,3:4)=[section%d(1,2) section%d(1,3)];',loop,loop,loop));
    eval(sprintf('output(%d,11:12)=[section%d(numrows(%d),2) section%d(numrows(%d),3)];',loop,loop,loop,loop,loop));
  end;
  sectsciencehours=output(numsec,6) + output(numsec,7);
  hourslostpersect=sectsciencehours/totalsciencetime * hourslost;
  output(numsec,8)=hourslostpersect;
  fudgehourspersect=sectsciencehours/totalsciencetime * hoursfudge;
  output(numsec,9)=fudgehourspersect;
  endsecjd=output(numsec,2) + sectsciencehours/24 + hourslostpersect/24 + fudgehourspersect/24;
  output(numsec,10)=endsecjd;
  eval(sprintf('output(%d,3:4)=[section%d(1,2) section%d(1,3)];',numsec,numsec,numsec));
  eval(sprintf('output(%d,11:12)=[section%d(numrows(%d),2) section%d(numrows(%d),3)];',numsec,numsec,numsec,numsec,numsec));
end;

% Compute end date and display quick stats box
if isempty(numsec)
  endjd=output(1,10) + t2time/24;
else
  endjd=output(numsec,10) + t2time/24;
end;
startdate=cl_ctgrg(beginjd);
enddate=cl_ctgrg(endjd);
startend=cell(11,1);
if startdate(4) < 10
  shrstring=cat(2,'0',num2str(startdate(4)));
else
  shrstring=cat(2,num2str(startdate(4)));
end;
if startdate(5) < 10
  sminstring=cat(2,'0',num2str(startdate(5)));
else
  sminstring=cat(2,num2str(startdate(5)));
end;
if enddate(4) < 10
  ehrstring=cat(2,'0',num2str(enddate(4)));
else
  ehrstring=cat(2,num2str(enddate(4)));
end;
if enddate(5) < 10
  eminstring=cat(2,'0',num2str(enddate(5)));
else
  eminstring=cat(2,num2str(enddate(5)));
end;
startend{1}='';
startend{2}=cat(2,'Departure time: ',num2str(startdate(2)),'/',num2str(startdate(3)),'/',num2str(startdate(1)),' ',shrstring,sminstring);
startend{3}=cat(2,'Arrival time:   ',num2str(enddate(2)),'/',num2str(enddate(3)),'/',num2str(enddate(1)),' ',ehrstring,eminstring);
startend{4}=' ';
days=floor(t1time/24); hrs=t1time - days*24; mins=round((hrs - floor(hrs)) * 60);
startend{5}=cat(2,'Time to first station: ',num2str(days),' days, ',num2str(floor(hrs)),' hr ',num2str(mins),' min');
days=floor(sum(sectiontime)/24); hrs=sum(sectiontime) - days*24; mins=round((hrs - floor(hrs)) * 60);
startend{6}=cat(2,'Science steaming time: ',num2str(days),' days, ',num2str(floor(hrs)),' hr ',num2str(mins),' min');
days=floor(sum(onstatime)/24); hrs=sum(onstatime) - days*24; mins=round((hrs - floor(hrs)) * 60);
startend{7}=cat(2,'Science wire time: ',num2str(days),' days, ',num2str(floor(hrs)),' hr ',num2str(mins),' min');
days=floor(sum(transittime)/24); hrs=sum(transittime) - days*24; mins=round((hrs - floor(hrs)) * 60);
startend{8}=cat(2,'Transit time: ',num2str(days),' days, ',num2str(floor(hrs)),' hr ',num2str(mins),' min');
days=floor(t2time/24); hrs=t2time - days*24; mins=round((hrs - floor(hrs)) * 60);
startend{9}=cat(2,'Time from last station: ',num2str(days),' days, ',num2str(floor(hrs)),' hr ',num2str(mins),' min');
days=floor(hourslost/24); hrs=hourslost - days*24; mins=round((hrs - floor(hrs)) * 60);
startend{10}=cat(2,'Lost time due to weather: ',num2str(days),' days, ',num2str(floor(hrs)),' hr ',num2str(mins),' min');
days=floor(hoursfudge/24); hrs=hoursfudge - days*24; mins=round((hrs - floor(hrs)) * 60);
startend{11}=cat(2,'Lost time to misc events: ',num2str(days),' days, ',num2str(floor(hrs)),' hr ',num2str(mins),' min');
days=floor(totaldays); hrs=(totaldays - days)*24; mins=round((hrs - floor(hrs)) * 60);
startend{12}=cat(2,'Total cruise time: ',num2str(days),' days, ',num2str(floor(hrs)),' hr ',num2str(mins),' min');

if(daybox)
  h=msgbox(startend,'Cruise quick stats');
end;

% Calculate gregorian pretty output for times of start of sections

waypointdates=cl_ctgrg(output(:,2)); % 1/2/3/4/5/6 yr/mo/day/hr/min/sec
if isempty(numsec)
  waypoints=cell(1,1);
  if waypointdates(1,4) < 10
    hrstring=cat(2,'0',num2str(waypointdates(1,4)));
  else
    hrstring=cat(2,num2str(waypointdates(1,4)));
  end;
  if waypointdates(1,5) < 10
    minstring=cat(2,'0',num2str(waypointdates(1,5)));
  else
    minstring=cat(2,num2str(waypointdates(1,5)));
  end;
  % Use this line if you want the year in the waypoints
  %waypoints{1}=cat(2,num2str(waypointdates(1,2)),'/',num2str(waypointdates(1,3)),'/',num2str(waypointdates(1,1)),' ',hrstring,minstring);  
  waypoints{1}=cat(2,num2str(waypointdates(1,2)),'/',num2str(waypointdates(1,3)),' ',hrstring,minstring);  
else
  waypoints=cell(numsec,1);
  for loop=1:numsec
    if waypointdates(loop,4) < 10
      hrstring=cat(2,'0',num2str(waypointdates(loop,4)));
    else
      hrstring=cat(2,num2str(waypointdates(loop,4)));
    end;
    if waypointdates(loop,5) < 10
      minstring=cat(2,'0',num2str(waypointdates(loop,5)));
    else
      minstring=cat(2,num2str(waypointdates(loop,5)));
    end;
    % Use this line if you want the year in the waypoints
    %waypoints{loop}=cat(2,num2str(waypointdates(loop,2)),'/',num2str(waypointdates(loop,3)),'/',num2str(waypointdates(loop,1)),' ',hrstring,minstring);
    waypoints{loop}=cat(2,num2str(waypointdates(loop,2)),'/',num2str(waypointdates(loop,3)),' ',hrstring,minstring);
 end;
end;

% Calculate gregorian pretty output for times of end of sections

ewaypointdates=cl_ctgrg(output(:,10)); % 1/2/3/4/5/6 yr/mo/day/hr/min/sec
if isempty(numsec)
  ewaypoints=cell(1,1);
  if ewaypointdates(1,4) < 10
    hrstring=cat(2,'0',num2str(ewaypointdates(1,4)));
  else
    hrstring=cat(2,num2str(ewaypointdates(1,4)));
  end;
  if waypointdates(1,5) < 10
    minstring=cat(2,'0',num2str(ewaypointdates(1,5)));
  else
    minstring=cat(2,num2str(ewaypointdates(1,5)));
  end;
  % Use this line if you want the year in the waypoints
  %ewaypoints{1}=cat(2,num2str(ewaypointdates(1,2)),'/',num2str(ewaypointdates(1,3)),'/',num2str(ewaypointdates(1,1)),' ',hrstring,minstring);
  ewaypoints{1}=cat(2,num2str(ewaypointdates(1,2)),'/',num2str(ewaypointdates(1,3)),' ',hrstring,minstring);
else
  ewaypoints=cell(numsec,1);
  for loop=1:numsec
    if ewaypointdates(loop,4) < 10
      hrstring=cat(2,'0',num2str(ewaypointdates(loop,4)));
    else
      hrstring=cat(2,num2str(ewaypointdates(loop,4)));
    end;
    if ewaypointdates(loop,5) < 10
      minstring=cat(2,'0',num2str(ewaypointdates(loop,5)));
    else
      minstring=cat(2,num2str(ewaypointdates(loop,5)));
    end;
    % Use this line if you want the year in the waypoints
    %ewaypoints{loop}=cat(2,num2str(ewaypointdates(loop,2)),'/',num2str(ewaypointdates(loop,3)),'/',num2str(ewaypointdates(loop,1)),' ',hrstring,minstring);
    ewaypoints{loop}=cat(2,num2str(ewaypointdates(loop,2)),'/',num2str(ewaypointdates(loop,3)),' ',hrstring,minstring);
  end;
end;

if(saveoutchoice) & (daybox)
  answers=inputdlg({'Enter output file prefix',},'Save files',[1],{'cruiseout'});
  if(isempty(answers))
  else
  ctoutfile=answers{1};
  fid=fopen(ctoutfile,'w');
  fprintf(fid,' ** Cruise name: %12s',inputfile);
  fprintf(fid,' \n\n');
  fprintf(fid,' ** TO FIRST STATION time =  %9.2f hours (%6.2f days) at  %4.1f knots  ** Rate for sections = %4.1f knots\n',t1time,t1time/24,speedtransit,speedsec);
  fprintf(fid,' \n');
  fprintf(fid,'sec  *start pos.*   *stop pos.*   Num  Steam onSta Wethr  Misc  Total  *days hr mm*  *start date*  *stop date* Steam to\n');  
  fprintf(fid,'                                  sta  hrs.  hrs.  hrs.   hrs.   hrs.  ------------   mm/dd hhmm    mm/dd hhmm next (hrs)\n');
  fprintf(fid,' \n'); 
  if isempty(numsec) | numsec==1
    loop=1;
    totsechrs = sum(output(loop,6:9)); days=floor(totsechrs/24); hrs=totsechrs - days*24; mins=round((hrs - floor(hrs)) * 60);
    fprintf(fid,'%3.0f %6.2f %7.2f %6.2f %7.2f %3.0f %5.1f %5.1f %5.1f %5.1f %7.2f =%3.0f %3.0f %3.0f %13s %13s %7.2f\n', loop,output(loop,3),output(loop,4), output(loop,11), output(loop,12), output(loop,5), output(loop,6), output(loop,7), output(loop,8), output(loop,9), totsechrs, days, hrs, mins, waypoints{loop}, ewaypoints{loop}, output(loop,13));    
  else
    for loop=1:numsec
      totsechrs = sum(output(loop,6:9)); days=floor(totsechrs/24); hrs=totsechrs - days*24; mins=round((hrs - floor(hrs)) * 60);
      fprintf(fid,'%3.0f %6.2f %7.2f %6.2f %7.2f %3.0f %5.1f %5.1f %5.1f %5.1f %7.2f =%3.0f %3.0f %3.0f %13s %13s %7.2f\n', loop,output(loop,3),output(loop,4), output(loop,11), output(loop,12), output(loop,5), output(loop,6), output(loop,7), output(loop,8), output(loop,9), totsechrs, days, hrs, mins, waypoints{loop}, ewaypoints{loop}, output(loop,13));
    end;
  end;
  fprintf(fid,' \n');
  fprintf(fid,'TOTAL in hours = %20.0f %5.1f %5.1f %5.1f %5.1f %7.2f %48.2f\n',sum(output(:,5)),sum(output(:,6)),sum(output(:,7)), sum(output(:,8)),  sum(output(:,9)), sum(sum(output(:,6:9))), sum(output(:,13)) );
  fprintf(fid,' \n');
  fprintf(fid,'TOTAL in days = %27.1f %5.1f %5.1f %5.1f %7.2f %48.2f\n', sum(output(:,6))/24,sum(output(:,7))/24, sum(output(:,8))/24,  sum(output(:,9))/24, sum(sum(output(:,6:9)))/24, sum(output(:,13))/24) ;
  fprintf(fid,'\n');
  fprintf(fid,'Station time computed using wire rate of %4.0f minutes RT per 1000m of depth\n',wiretime);
  fprintf(fid,' \n');
  fprintf(fid,' ** LAST STATION TO PORT time = %9.2f hours (%6.2f days) at %4.1f knots \n', t2time, t2time/24, speedtransit);
  fprintf(fid,' **\n');
  fprintf(fid,' ** %30s\n',startend{2});
  fprintf(fid,' **  %30s\n',startend{3});
  fprintf(fid,' **\n');
  fprintf(fid,' ** TOTAL CRUISE time PORT to PORT = %5.2f days \n',totaldays);
  fprintf(fid,' \n');
  fprintf(fid,' WEATHER FACTOR -- 1 added for every %4.0f\n',weather);
  fprintf(fid,' \n');
  fprintf(fid,' EXTRA TIME for BAD WEATHER *NOT* INCLUDED in transit legs between stations or transits to/from ports\n');
  fclose(fid);
  end;
end;


% This segment computes the estimated times for each station, output ONLY as text files if you choose saveout.
if(saveoutchoice) & (daybox)
   if isempty(numsec) | numsec==1
      loop=1;
      fancyoutfile=[ctoutfile '_1'];
      fid=fopen(fancyoutfile,'w');
      fprintf(fid,' ** Section #1 **\n\n');
      fprintf(fid,'     Time @ start                                 Time @ end   Dst to         CastTime  Transit  \n'); 
      fprintf(fid,'Sta  Mo DD HH Mi   Latitude   Longitude   Dep(m)  Mo DD HH Mi  Nxt(nm) TotDst  (hrs)   Time(hrs)\n');
      sectiontime=[sw_dist(section1(:,2),section1(:,3))/speedsec; 0];
      sectiondist=[sw_dist(section1(:,2),section1(:,3),'nm'); 0];
      sectioncumdist=cumsum(sectiondist);
      depthofcast=abs(section1(:,4));
      onstatime=depthofcast * wirerate;      
      timebegsta=ones(size(section1,1),1)*startsecjd; 
      timeendsta=ones(size(section1,1),1)*(startsecjd + onstatime(1)/24);
      if size(section1,1) > 1
         for subloop=2:size(section1,1)
            timebegsta(subloop)=timeendsta(subloop-1) + sectiontime(subloop-1)/24;
            timeendsta(subloop)=timebegsta(subloop) + onstatime(subloop)/24;            
         end;
      end;
      timebegstagrg=cl_ctgrg(timebegsta);
      timeendstagrg=cl_ctgrg(timeendsta);
      for subloop=1:size(section1,1)
         latd=fix(section1(subloop,2));
         latm=abs((section1(subloop,2)-latd)*60);
         lond=fix(section1(subloop,3));
         lonm=abs((section1(subloop,3)-lond)*60);
         fprintf(fid,'%3.0f %3.0f %2.0f %2.0f %2.0f %4.0f %6.2f %4.0f %6.2f %7.1f %3.0f %2.0f %2.0f %2.0f %7.2f %7.2f %7.2f %7.2f\n',section1(subloop,1),timebegstagrg(subloop,2:5),latd,latm,lond,lonm,section1(subloop,4),timeendstagrg(subloop,2:5),sectiondist(subloop),sectioncumdist(subloop),onstatime(subloop),sectiontime(subloop));    
      end;
      fprintf(fid,'\n ** Total time = %5.2f hours **\n',(timeendsta(size(section1,1))-timebegsta(1))*24);
      fclose(fid);
   else
      for loop=1:numsec
         fancyoutfile=[ctoutfile '_' num2str(loop)];
         fid=fopen(fancyoutfile,'w');
         fprintf(fid,' ** Section #%2.0f **\n\n',loop);
         fprintf(fid,'     Time @ start                                 Time @ end   Dst to         CastTime  Transit  \n');
         fprintf(fid,'Sta  Mo DD HH Mi   Latitude   Longitude   Dep(m)  Mo DD HH Mi  Nxt(nm) TotDst  (hrs)   Time(hrs)\n');
         eval(sprintf('workingsec=section%d;',loop));
         sectiontime=[sw_dist(workingsec(:,2),workingsec(:,3))/speedsec; 0];
         sectiondist=[sw_dist(workingsec(:,2),workingsec(:,3),'nm'); 0];
         sectioncumdist=cumsum(sectiondist);
         depthofcast=abs(workingsec(:,4));
         onstatime=depthofcast * wirerate;      
         begtime=cl_ctjd(waypointdates(loop,1),waypointdates(loop,2),waypointdates(loop,3),waypointdates(loop,4)) + waypointdates(loop,5) / (60*24) + waypointdates(loop,6) / (60*60*24);
         timebegsta=ones(size(workingsec,1),1)*begtime; 
         timeendsta=ones(size(workingsec,1),1)*(begtime + onstatime(1)/24);
         if size(workingsec,1) > 1
            for subloop=2:size(workingsec,1)
               timebegsta(subloop)=timeendsta(subloop-1) + sectiontime(subloop-1)/24;
               timeendsta(subloop)=timebegsta(subloop) + onstatime(subloop)/24;            
            end;
         end;
         timebegstagrg=cl_ctgrg(timebegsta);
         timeendstagrg=cl_ctgrg(timeendsta);
         for subloop=1:size(workingsec,1)
            latd=fix(workingsec(subloop,2));
            latm=abs((workingsec(subloop,2)-latd)*60);
            lond=fix(workingsec(subloop,3));
            lonm=abs((workingsec(subloop,3)-lond)*60);
            fprintf(fid,'%3.0f %3.0f %2.0f %2.0f %2.0f %4.0f %6.2f %4.0f %6.2f %7.1f %3.0f %2.0f %2.0f %2.0f %7.2f %7.2f %7.2f %7.2f\n',workingsec(subloop,1),timebegstagrg(subloop,2:5),latd,latm,lond,lonm,workingsec(subloop,4),timeendstagrg(subloop,2:5),sectiondist(subloop),sectioncumdist(subloop),onstatime(subloop),sectiontime(subloop));    
         end;
         fprintf(fid,'\n ** Total time = %5.2f hours **\n',(timeendsta(size(workingsec,1))-timebegsta(1))*24);
         fclose(fid);
      end;
   end;

end;



end; %ctgoodflag



