% cl_ctplot.m
%
% Cruisetrack plotting code
% 
% Usage: cl_ct
% Click on help buttons for tips.
% Version 1.7, 11 June 2008, Chris Linder
%

% Error check
cl_cterror;

if(cbgoodflag)

% Need to load all of the applicable track data
% First, if number of sections is 1, then just load the inputfile
% or, if number of sections > 1, then load all sections.

% Create mercator map 
ft=maxlat-minlat;
fn=maxlon-minlon;
f=figure;
title('Drawing basemap...');
m_proj('Mercator','lon',[minlon maxlon],'lat',[minlat maxlat]);
m_grid('box','fancy'); 
hold on;
title('Drawing basemap...');

% Coastline plotting
if(clchoice)
  title('Plotting coastline...');
  figure(f);
  if exist('m_gshhs_l')==0
    m_coast('patch',[.5 .5 .5]);
  else
    if fn > 50
      m_gshhs_c('patch',[.5 .5 .5]);
    elseif fn > 11
      m_gshhs_l('patch',[.5 .5 .5]);
    elseif fn > 1
      m_gshhs_i('patch',[.5 .5 .5]);
    else
      m_gshhs_h('patch',[.5 .5 .5]);
    end;
  end;
end; % Coastline plotting

% Bathymetry plotting
if(btchoice)
  title('Plotting bathymetry...');
  figure(f);
  % Extract and plot...
  switch btmode
  case 1
    [data,LON,LAT]=m_etopo2([minlon maxlon minlat maxlat]);
  case 2
    [data,LON,LAT]=m_tbase([minlon maxlon minlat maxlat]);
  case 3
    if exist(btfile) == 2
       eval(sprintf('load %s;',btfile));

    else
      [data,LON,LAT]=m_tbase([minlon maxlon minlat maxlat]); figure(f);
    end;
  end;
  if size(btcontours,2)==1 btcontours=[btcontours btcontours]; end;
  [c,h]=m_contour(LON,LAT,data,btcontours,'k');
  if isempty(c) == 0
     clabel(c,h);
  end;
end; % Bathymetry plotting

% Misc Lon/Lat file plotting
if(miscchoice)
  if exist(miscfile)==2
    title('Plotting lat/lon file...');
    figure(f);
    eval(sprintf('iedata=load(''%s'');',miscfile));
    % This assumes we have a 2 column ASCII file of (1) lats (2) lons to plot
    lats=iedata(:,2);
    lons=iedata(:,1);
    m_plot(lons,lats,'m');
    hold on;
    m_plot(lons,lats,'m.');
    hold on;
  end;
end; % Misc Lon/Lat file plotting

% Refresh fancy box (but NOT before cruisetrack plotting, or box will refresh in pop-up window!

m_grid('box','fancy');
set(findobj('tag','m_grid_color'),'facecolor','none');

% Plot all of the cruisetrack data

if(ctchoice)
  title('Plotting track...');
  cl_ctloadcomp;
  if(ctgoodflag)   
    err=0.1; %offset for m_text   
    figure(f);
    if isempty(t1) == 0
      m_plot(t1(:,3),t1(:,2),'g'); hold on;
      m_text(t1(1,3)+err,t1(1,2)+2*err,'Begin','color','b');
    end;
    if numsec==1 | isempty(numsec)
      htext=m_text(output(1,4)+err,output(1,3)+err,['Start #1'],'color','b');
      m_plot(section1(:,3),section1(:,2),'r'); hold on;
      m_plot(section1(:,3),section1(:,2),'k.'); 
      m_plot(section1(:,3),section1(:,2),'ro');  
      % Comment this in if you want station numbers
      %m_text(section1(:,3)+err,section1(:,2)+err,num2str(section1(:,1)));
      htext=m_text(output(1,12)+err,output(1,11)+err,['End #1'],'color','b');
    else
      for loop=1:numsec-1
        htext=m_text(output(loop,4)+err,output(loop,3)+err,['Start #',num2str(output(loop,1)),''],'color','b');
        eval(sprintf('m_plot(section%d(:,3),section%d(:,2),''r'');',loop,loop)); hold on;
        eval(sprintf('m_plot(section%d(:,3),section%d(:,2),''k.'');',loop,loop));
        eval(sprintf('m_plot(section%d(:,3),section%d(:,2),''ro'');',loop,loop)); 
        pause(0.1);
        % Comment this in if you want station numbers
        %eval(sprintf('m_text(section%d(:,3)+err,section%d(:,2)+err,num2str(section%d(:,1)));',loop,loop,loop));
        htext=m_text(output(loop,12)+err,output(loop,11)+err,['End #',num2str(output(loop,1)),''],'color','b');
        % Plot transit legs between sections...
        eval(sprintf('m_plot(transit%d(:,3),transit%d(:,2),''g'');',loop,loop));    
      end;
      htext=m_text(output(numsec,4)+err,output(numsec,3)+err,['Start #',num2str(output(numsec,1)),''],'color','b');
      eval(sprintf('m_plot(section%d(:,3),section%d(:,2),''r'');',numsec,numsec)); hold on;
      eval(sprintf('m_plot(section%d(:,3),section%d(:,2),''k.'');',numsec,numsec)); 
      eval(sprintf('m_plot(section%d(:,3),section%d(:,2),''ro'');',numsec,numsec));
      % Comment this in if you want station numbers
      %eval(sprintf('m_text(section%d(:,3)+err,section%d(:,2)+err,num2str(section%d(:,1)));',numsec,numsec,numsec));
      htext=m_text(output(numsec,12)+err,output(numsec,11)+err,['End #',num2str(output(numsec,1)),''],'color','b');
    end;
    if isempty(t2) == 0
      m_plot(t2(:,3),t2(:,2),'g');
      [r,c]=size(t2);
      m_text(t2(r,3)+err,t2(r,2)-2*err,'End','color','b');
    end;
    %Make fancy msgbox using cell arrays
    % Need to cat all gregorian date nums into strings.
    % Calculate gregorian pretty output for times of start of sections
    % Use ewaypoints for end of sections...
    if isempty(numsec)
      plotwaypoints=cell(6,1);
      plotwaypoints{1}='#  Date  Time';
      plotwaypoints{2}=' ';
      plotwaypoints{3}=startend{2};
      plotwaypoints{4}=cat(2,'1 start:  ',waypoints{1});
      plotwaypoints{5}=cat(2,'1 end  :  ',ewaypoints{1});
      plotwaypoints{6}=startend{3};
    else
      plotwaypoints=cell(numsec*2 + 4,1);
      plotwaypoints{1}='#  Date  Time';
      plotwaypoints{2}=' ';
      plotwaypoints{3}=startend{2};
      loop=4; sectionloop=1;
      while loop < numsec*2 + 4
        plotwaypoints{loop}=cat(2,num2str(sectionloop),' start:  ',waypoints{sectionloop});
        plotwaypoints{loop+1}=cat(2,num2str(sectionloop),' end  :  ',ewaypoints{sectionloop});
        loop=loop+2; sectionloop=sectionloop+1;
      end;
      plotwaypoints{numsec*2+4}=startend{3};
    end;
    title('');
    h=msgbox(plotwaypoints,'Waypoints');
  end; %ctgoodflag
else
  title('');
end; %ctchoice plotting


end; %cbgoodflag

